@@ -2,7 +2,7 @@ from datetime import date
 import enum
 from typing import Any, Dict, Optional
 import pandas as pd
-
+from google.protobuf.wrappers_pb2 import DoubleValue
 
 def filter_nones_from_dict(query_parameters: Dict[str, Optional[Any]]) -> Dict[str, Any]:
     return {k: v for k, v in query_parameters.items() if v}
@@ -47,6 +47,19 @@ def validate(kwargs):
             kwargs[key] = value.isoformat()
     return filter_nones_from_dict(kwargs)
 
+def wrapPoints(kwargs):
+    for key, value in kwargs.items():
+        if key == "locations":
+            for index, item in enumerate(value):
+                for key, value in item.items():
+                    if key == "point":
+                        kwargs["locations"][index]["point"]["lon"] = DoubleValue(value=value["lon"])
+                        kwargs["locations"][index]["point"]["lat"] = DoubleValue(value=value["lat"])
+
+
+    return filter_nones_from_dict(kwargs)
+
+
 
 def pb_list_to_pandas(data):
 
