@@ -41,11 +41,11 @@ def partition(
 class tradeflowsCallTransformer(cst.CSTTransformer):
     CTRL_PARAMS: Tuple[str] = ('retry', 'timeout', 'metadata')
     METHOD_TO_PARAMS: Dict[str, Tuple[str]] = {
-    'get_location_data': ('frequency', 'commodity', 'commodity_group', 'flow_direction', 'imo', 'load_port_id', 'load_port_unlocode', 'load_berth_id', 'discharge_port_id', 'discharge_port_unlocode', 'discharge_berth_id', 'segment', 'sub_segment', 'start_date', 'end_date', 'load_country_code', 'discharge_country_code', 'load_region', 'discharge_region', 'status', 'exclude_intra_country', 'exclude_unknown_destinations', 'exclude_missing_load_berth', 'exclude_missing_discharge_berth', 'next_token', 'max_results', 'format_', 'group_by', 'pivot_by', 'tall_format', 'metric', 'parceling', 'limit_groups', 'last_n_days', 'sort', ),
-    'get_trade_flow_aggregation': ('frequency', 'commodity', 'commodity_group', 'flow_direction', 'imo', 'load_port_id', 'load_port_unlocode', 'load_berth_id', 'discharge_port_id', 'discharge_port_unlocode', 'discharge_berth_id', 'segment', 'sub_segment', 'start_date', 'end_date', 'load_country_code', 'discharge_country_code', 'load_region', 'discharge_region', 'status', 'exclude_intra_country', 'exclude_unknown_destinations', 'exclude_missing_load_berth', 'exclude_missing_discharge_berth', 'next_token', 'max_results', 'format_', 'group_by', 'pivot_by', 'tall_format', 'metric', 'parceling', 'limit_groups', 'last_n_days', 'sort', ),
-    'get_trade_flow_histogram': ('frequency', 'commodity', 'commodity_group', 'flow_direction', 'imo', 'load_port_id', 'load_port_unlocode', 'load_berth_id', 'discharge_port_id', 'discharge_port_unlocode', 'discharge_berth_id', 'segment', 'sub_segment', 'start_date', 'end_date', 'load_country_code', 'discharge_country_code', 'load_region', 'discharge_region', 'status', 'exclude_intra_country', 'exclude_unknown_destinations', 'exclude_missing_load_berth', 'exclude_missing_discharge_berth', 'next_token', 'max_results', 'format_', 'group_by', 'pivot_by', 'tall_format', 'metric', 'parceling', 'limit_groups', 'last_n_days', 'sort', ),
-    'get_trade_flows': ('frequency', 'commodity', 'commodity_group', 'flow_direction', 'imo', 'load_port_id', 'load_port_unlocode', 'load_berth_id', 'discharge_port_id', 'discharge_port_unlocode', 'discharge_berth_id', 'segment', 'sub_segment', 'start_date', 'end_date', 'load_country_code', 'discharge_country_code', 'load_region', 'discharge_region', 'status', 'exclude_intra_country', 'exclude_unknown_destinations', 'exclude_missing_load_berth', 'exclude_missing_discharge_berth', 'next_token', 'max_results', 'format_', 'group_by', 'pivot_by', 'tall_format', 'metric', 'parceling', 'limit_groups', 'last_n_days', 'sort', ),
-    'get_trade_flow_timeseries': ('frequency', 'commodity', 'commodity_group', 'flow_direction', 'imo', 'load_port_id', 'load_port_unlocode', 'load_berth_id', 'discharge_port_id', 'discharge_port_unlocode', 'discharge_berth_id', 'segment', 'sub_segment', 'start_date', 'end_date', 'load_country_code', 'discharge_country_code', 'load_region', 'discharge_region', 'status', 'exclude_intra_country', 'exclude_unknown_destinations', 'exclude_missing_load_berth', 'exclude_missing_discharge_berth', 'next_token', 'max_results', 'format_', 'group_by', 'pivot_by', 'tall_format', 'metric', 'parceling', 'limit_groups', 'last_n_days', 'sort', ),
+    'get_location_data': ('frequency', 'commodity', 'commodity_group', 'flow_direction', 'imo', 'load_port_id', 'load_port_unlocode', 'load_berth_id', 'discharge_port_id', 'discharge_port_unlocode', 'discharge_berth_id', 'segment', 'sub_segment', 'start_date', 'end_date', 'load_country_code', 'discharge_country_code', 'load_region', 'discharge_region', 'status', 'exclude_intra_country', 'exclude_unknown_destinations', 'exclude_missing_load_berth', 'exclude_missing_discharge_berth', 'next_token', 'max_results', 'format_', 'group_by', 'pivot_by', 'tall_format', 'metric', 'parceling', 'limit_groups', 'last_n_days', 'sort', 'dwt', ),
+    'get_trade_flow_aggregation': ('frequency', 'commodity', 'commodity_group', 'flow_direction', 'imo', 'load_port_id', 'load_port_unlocode', 'load_berth_id', 'discharge_port_id', 'discharge_port_unlocode', 'discharge_berth_id', 'segment', 'sub_segment', 'start_date', 'end_date', 'load_country_code', 'discharge_country_code', 'load_region', 'discharge_region', 'status', 'exclude_intra_country', 'exclude_unknown_destinations', 'exclude_missing_load_berth', 'exclude_missing_discharge_berth', 'next_token', 'max_results', 'format_', 'group_by', 'pivot_by', 'tall_format', 'metric', 'parceling', 'limit_groups', 'last_n_days', 'sort', 'dwt', ),
+    'get_trade_flow_histogram': ('frequency', 'commodity', 'commodity_group', 'flow_direction', 'imo', 'load_port_id', 'load_port_unlocode', 'load_berth_id', 'discharge_port_id', 'discharge_port_unlocode', 'discharge_berth_id', 'segment', 'sub_segment', 'start_date', 'end_date', 'load_country_code', 'discharge_country_code', 'load_region', 'discharge_region', 'status', 'exclude_intra_country', 'exclude_unknown_destinations', 'exclude_missing_load_berth', 'exclude_missing_discharge_berth', 'next_token', 'max_results', 'format_', 'group_by', 'pivot_by', 'tall_format', 'metric', 'parceling', 'limit_groups', 'last_n_days', 'sort', 'dwt', ),
+    'get_trade_flows': ('frequency', 'commodity', 'commodity_group', 'flow_direction', 'imo', 'load_port_id', 'load_port_unlocode', 'load_berth_id', 'discharge_port_id', 'discharge_port_unlocode', 'discharge_berth_id', 'segment', 'sub_segment', 'start_date', 'end_date', 'load_country_code', 'discharge_country_code', 'load_region', 'discharge_region', 'status', 'exclude_intra_country', 'exclude_unknown_destinations', 'exclude_missing_load_berth', 'exclude_missing_discharge_berth', 'next_token', 'max_results', 'format_', 'group_by', 'pivot_by', 'tall_format', 'metric', 'parceling', 'limit_groups', 'last_n_days', 'sort', 'dwt', ),
+    'get_trade_flow_timeseries': ('frequency', 'commodity', 'commodity_group', 'flow_direction', 'imo', 'load_port_id', 'load_port_unlocode', 'load_berth_id', 'discharge_port_id', 'discharge_port_unlocode', 'discharge_berth_id', 'segment', 'sub_segment', 'start_date', 'end_date', 'load_country_code', 'discharge_country_code', 'load_region', 'discharge_region', 'status', 'exclude_intra_country', 'exclude_unknown_destinations', 'exclude_missing_load_berth', 'exclude_missing_discharge_berth', 'next_token', 'max_results', 'format_', 'group_by', 'pivot_by', 'tall_format', 'metric', 'parceling', 'limit_groups', 'last_n_days', 'sort', 'dwt', ),
 
     }
 
